diff --git a/web/content/docs/tools/fileio/GocadTSurfaceReader/index.pandoc b/web/content/docs/tools/fileio/GocadTSurfaceReader/index.pandoc
index e6e4ac96820a41e96505d4e938e429a5dd38a64b..3cb60b0b3785cabe5575b56563a60abbb067bb0a 100644
--- a/web/content/docs/tools/fileio/GocadTSurfaceReader/index.pandoc
+++ b/web/content/docs/tools/fileio/GocadTSurfaceReader/index.pandoc
@@ -29,8 +29,8 @@ The tool is part of the official [OpenGeoSys git repository](https://github.com/
 ## Usage
 
 ```bash
-   GocadTSurfaceReader.exe  -i <filename.ts> -o <output dir> [-l] [-s] [-b]
-                            [--] [--version] [-h]
+   GocadTSurfaceReader  -i <filename.ts> -o <output dir> [-l] [-s] [-b]
+                        [--] [--version] [-h]
 
 
 Where:
diff --git a/web/content/docs/tools/fileio/Mesh2Shape/index.pandoc b/web/content/docs/tools/fileio/Mesh2Shape/index.pandoc
index b47174f568e058acaaa3dc5f6c35d9160cbca04d..ca7bf692bec0f883b77e0eb423cd77fbe172fb7f 100644
--- a/web/content/docs/tools/fileio/Mesh2Shape/index.pandoc
+++ b/web/content/docs/tools/fileio/Mesh2Shape/index.pandoc
@@ -17,7 +17,7 @@ The tool is part of the official [OpenGeoSys git repository](https://github.com/
 ## Usage
 
 ```bash
-   Mesh2Shape.exe  -i <input_file.vtu> -o <output_file.shp>
+   Mesh2Shape  -i <input_file.vtu> -o <output_file.shp>
 
 
 Where:
@@ -34,11 +34,11 @@ Where:
 **Input data:**
 
 ![](./Mesh2Shape-input.png){ width=66% }
-2D surface mesh mit scalar data assigned to cells, here displayed via the OGS Data Explorer. In this particular case, the simulation result of groundwater flow simulation (originally assigned to mesh nodes) has been converted onto cells via VTK's PointToCell-Filter.
+2D surface mesh with scalar data assigned to cells, here displayed via the OGS Data Explorer. In this particular case, the simulation result of groundwater flow simulation (originally assigned to mesh nodes) has been converted onto cells via VTK's PointToCell-Filter.
 
 **Command:**
 ```
-Mesh2Raster -i Mueglitz2D_Point2Cell.vtu -o Mueglitz2D_Point2Cell.shp
+Mesh2Shape -i Mueglitz2D_Point2Cell.vtu -o Mueglitz2D_Point2Cell.shp
 ```
 
 ![](./Mesh2Shape-output1.png){ width=66% }
diff --git a/web/content/docs/tools/fileio/TecPlotTools/index.pandoc b/web/content/docs/tools/fileio/TecPlotTools/index.pandoc
index ad0f9da2e1e55472d25c6c0553f0940588b5aa24..5681865b1800985bc64a3c1ab4d1fd684bb4c6d1 100644
--- a/web/content/docs/tools/fileio/TecPlotTools/index.pandoc
+++ b/web/content/docs/tools/fileio/TecPlotTools/index.pandoc
@@ -19,7 +19,7 @@ The tool is part of the official [OpenGeoSys git repository](https://github.com/
 ## Usage
 
 ```bash
-   TecPlotTools.exe  -i <string> [-o <string>] [-c] [-s]
+   TecPlotTools -i <string> [-o <string>] [-c] [-s]
 
 
 Where:
@@ -34,7 +34,7 @@ Where:
      convert TecPlot data into OGS meshes
 
    -s,  --split
-     split time steps into seperate files
+     split time steps into separate files
 ```
 
 ## Simple example
diff --git a/Applications/Utils/FileConverter/TecPlotTools.cpp b/Applications/Utils/FileConverter/TecPlotTools.cpp
index 4bcf34cb909066c93a6ca958c85912603b91fd1c..4497eb48abeb21136574c57994e2fa57fa3d1e06 100644
--- a/Applications/Utils/FileConverter/TecPlotTools.cpp
+++ b/Applications/Utils/FileConverter/TecPlotTools.cpp
@@ -148,7 +148,7 @@ void resetDataStructures(std::size_t const& n_scalars,
     val_count = 0;
 }
 
 /// Writes one section/zone into a seperate TecPlot file
 void writeTecPlotSection(std::ofstream& out,
                          std::string const& file_name,
                          std::size_t& write_count,
@@ -169,7 +169,7 @@ void writeTecPlotSection(std::ofstream& out,
     }
 }
 
 /// Writes one section/zone into a seperate OGS-mesh
 int writeDataToMesh(std::string const& file_name,
                     std::size_t& write_count,
                     std::vector<std::string> const& vec_names,
@@ -239,7 +239,7 @@ void skipGeometrySection(std::ifstream& in, std::string& line)
     }
 }
 
 /// Splits a TecPlot file containing multiple sections/zones into seperate files
 int splitFile(std::ifstream& in, std::string file_name)
 {
     std::ofstream out;
@@ -419,7 +419,7 @@ int main(int argc, char* argv[])
             "(http://www.opengeosys.org)",
         ' ', GitInfoLib::GitInfo::ogs_version);
     TCLAP::SwitchArg split_arg("s", "split",
-        "split time steps into seperate files");
+        "split time steps into separate files");
     cmd.add(split_arg);
     TCLAP::SwitchArg convert_arg("c", "convert",
         "convert TecPlot data into OGS meshes");
@@ -148,7 +148,7 @@ void resetDataStructures(std::size_t const& n_scalars,
 }
 
-/// Writes one section/zone into a seperate TecPlot file
+/// Writes one section/zone into a separate TecPlot file
 void writeTecPlotSection(std::ofstream& out,
                          std::string const& file_name,
@@ -169,7 +169,7 @@ void writeTecPlotSection(std::ofstream& out,
 }
 
-/// Writes one section/zone into a seperate OGS-mesh
+/// Writes one section/zone into a separate OGS-mesh
 int writeDataToMesh(std::string const& file_name,
                     std::size_t& write_count,
@@ -239,7 +239,7 @@ void skipGeometrySection(std::ifstream& in, std::string& line)
 }
 
-/// Splits a TecPlot file containing multiple sections/zones into seperate files
+/// Splits a TecPlot file containing multiple sections/zones into separate files
 int splitFile(std::ifstream& in, std::string file_name)
 {